# Changelog

## Unreleased

## 1.14.0

* New ability to select seeds by convex area

## 1.11.0

* Update slice visualization on plugin run

## 1.10.0

* Brush size can be set on init

## 1.9.0

* Plugins moved to the top of the layout
* Refractoring of plugin class name

## 1.8.0

* Show status callable from plugin

## 1.7.0

* Plugin system introduced
* Pickup segmentation label

## 1.6.0

* Pickup seeds

## 1.5.0

* Keyboard shortcut for change label
* Keyboard shortcut for change brush

## 1.4.0
* Custom labels with selection from GUI added

## 1.3.0 

* Python 2 and python 3 compatibility